@@ -54,12 +54,14 @@ class Tredis_publish(threading.Thread):
             except queue.Empty:
                 pass
             else:
+                logger.info(f'real publish: {channel} {message}')
                 self.r.publish(channel, message)
                 self.queue_publish.task_done()
                 if channel == Tredis_publish.str_exit_magic_words and message == Tredis_publish.str_exit_magic_words:
                     break
 
     def publish(self, channel, message):
+        logger.info(f'queue publish: {channel} {message}')
         self.queue_publish.put((channel, message), block=True)
 
     def stop(self):
@@ -165,10 +167,11 @@ class Tredis:
 
     def stop(self):
         self.tredis_subscribe.stop()
-        self.tredis_subscribe.join()
         self.tredis_publish.stop()
-        self.tredis_publish.join()
 
+    def join(self):
+        self.tredis_subscribe.join()
+        self.tredis_publish.join()
 
 
 
